# Lazy_pratik_model
This package can be used in machine learning (Data Science) to check the performance of models.
The best thing about this package is that you don’t have to train and predict every classification or regression algorithm to check performance. This package directly gives you output performance on different models.
In Lazy_pratik_model
 there are two classes present which is smart_classifier(For Classification problems) and smart_regressor (for Regression problems).
Lazy_pratik_model for Classification: 

 will check the performance on this Classification models:
Passive Aggressive Classifier
Decision Tree Classifier
Random Forest Classifier
Extra Trees Classifier
Logistic Regression
Ridge Classifier
K Neighbors Classifier
Support Vector Classification
Naive Bayes Classifier
LGBM Classifier
CatBoost Classifier
XGB Classifier

And for classification problems Lazy_pratik_model can give the output of:
Accuracy Score.
Classification Report
Confusion Matrix
Cross validation (Cross validation score)
Mean Absolute Error
Mean Squared Error
Overfitting (will give accuracy of training and testing data.)
Precision Score
Recall Score

Lazy_pratik_model for Regression: 

Similarly, will check performance on this Regression model:
Passive Aggressive Regressor
Gradient Boosting Regressor
Decision Tree Regressor
Random Forest Regressor
Extra Trees Regressor
Lasso Regression
K Neighbors Regressor
Linear Regression
Support Vector Regression
LGBM Regressor
CatBoost Regressor
XGB Regressor

And for Regression problem Lazy_pratik_model
 can give an output of:
R2 Score.
Cross validation (Cross validation score)
Mean Absolute Error
Mean Squared Error
Overfitting (will give accuracy of training and testing data.)

Thank You!!.
